@@ -4,12 +4,19 @@ from django.core.urlresolvers import reverse as django_reverse
 from django.template.defaultfilters import stringfilter
 from django.utils.encoding import force_unicode, iri_to_uri
 from django.utils.text import Truncator, wrap, phone2numeric
-from django.utils.dateformat import format, time_format
+from django.utils.formats import date_format, time_format, number_format
 from django.utils.timesince import timesince, timeuntil
-from django.utils.html import escapejs, strip_tags
+from django.utils.html import escapejs, strip_tags, conditional_escape, fix_ampersands, \
+    escape, urlize as urlize_impl, linebreaks, strip_tags
+
+from django.utils.text import normalize_newlines
+from decimal import InvalidOperation, Decimal, ROUND_HALF_UP, Context
 from pprint import pformat
 from jinja2 import Markup
 
+import re
+import unicodedata
+
 def safe(value):
     return Markup(force_unicode(value))
 
@@ -106,7 +113,7 @@ def floatformat(text, arg=-1):
         return input_val
     
     if not m and p < 0:
-        return formats.number_format(u'%d' % (int(d)), 0)
+        return number_format(u'%d' % (int(d)), 0)
     
     if p == 0:
         exp = Decimal(1)
@@ -129,7 +136,7 @@ def floatformat(text, arg=-1):
         if sign:
             digits.append(u'-')
         number = u''.join(reversed(digits))
-        return formats.number_format(number, abs(p))
+        return number_format(number, abs(p))
     except InvalidOperation:
         return input_val
 
@@ -293,6 +300,10 @@ def add(value, arg):
         except Exception:
             return ''
 
+from django.utils import formats
+from django.utils.dateformat import format, time_format
+
+
 def date(value, arg=None):
     """Formats a date according to the given format."""
     if not value:
@@ -396,7 +407,7 @@ def filesizeformat(bytes):
     except (TypeError,ValueError,UnicodeDecodeError):
         return ungettext("%(size)d byte", "%(size)d bytes", 0) % {'size': 0}
 
-    filesize_number_format = lambda value: formats.number_format(round(value, 1), 1)
+    filesize_number_format = lambda value: number_format(round(value, 1), 1)
 
     if bytes < 1024:
         return ungettext("%(size)d byte", "%(size)d bytes", bytes) % {'size': bytes}
